@@ -70,6 +70,10 @@ class AyncExtractor:
         base_ex_req = self._get_base_ex_req(response)
         if base_ex_req is None:
             return res
+        #default values
+        base_ex_req[key_map["same_domain_only"]]= False
+        base_ex_req[key_map["allow_domains"]]=[]
+
         for rule in rules:
             ex_req = base_ex_req
             for key in [
